__all__: list[str] = []

# Functions
def addSamplesDataSearchPath(path: str) -> None: ...

def addSamplesDataSearchSubDirectory(subdir: str) -> None: ...

def findFile(relative_path: str, required: bool = ..., silentMode: bool = ...) -> str: ...

def findFileOrKeep(relative_path: str, silentMode: bool = ...) -> str: ...





__all__: list[str] = []

import cv2
import cv2.typing
import os
import typing as _typing


# Classes
class BarcodeDetector(cv2.GraphicalCodeDetector):
    # Functions
    @_typing.overload
    def __init__(self) -> None: ...
    @_typing.overload
    def __init__(self, prototxt_path: str | os.PathLike[str], model_path: str | os.PathLike[str]) -> None: ...

    @_typing.overload
    def decodeWithType(self, img: cv2.typing.MatLike, points: cv2.typing.MatLike) -> tuple[bool, _typing.Sequence[str], _typing.Sequence[str]]: ...
    @_typing.overload
    def decodeWithType(self, img: cv2.UMat, points: cv2.UMat) -> tuple[bool, _typing.Sequence[str], _typing.Sequence[str]]: ...

    @_typing.overload
    def detectAndDecodeWithType(self, img: cv2.typing.MatLike, points: cv2.typing.MatLike | None = ...) -> tuple[bool, _typing.Sequence[str], _typing.Sequence[str], cv2.typing.MatLike]: ...
    @_typing.overload
    def detectAndDecodeWithType(self, img: cv2.UMat, points: cv2.UMat | None = ...) -> tuple[bool, _typing.Sequence[str], _typing.Sequence[str], cv2.UMat]: ...

    def getDownsamplingThreshold(self) -> float: ...

    def setDownsamplingThreshold(self, thresh: float) -> BarcodeDetector: ...

    def getDetectorScales(self) -> _typing.Sequence[float]: ...

    def setDetectorScales(self, sizes: _typing.Sequence[float]) -> BarcodeDetector: ...

    def getGradientThreshold(self) -> float: ...

    def setGradientThreshold(self, thresh: float) -> BarcodeDetector: ...






__all__: list[str] = []

# Enumerations
LOG_LEVEL_SILENT: int
LOG_LEVEL_FATAL: int
LOG_LEVEL_ERROR: int
LOG_LEVEL_WARNING: int
LOG_LEVEL_INFO: int
LOG_LEVEL_DEBUG: int
LOG_LEVEL_VERBOSE: int
ENUM_LOG_LEVEL_FORCE_INT: int
LogLevel = int
"""One of [LOG_LEVEL_SILENT, LOG_LEVEL_FATAL, LOG_LEVEL_ERROR, LOG_LEVEL_WARNING, LOG_LEVEL_INFO, LOG_LEVEL_DEBUG, LOG_LEVEL_VERBOSE, ENUM_LOG_LEVEL_FORCE_INT]"""



# Functions
def getLogLevel() -> LogLevel: ...

def setLogLevel(logLevel: LogLevel) -> LogLevel: ...





__all__: list[str] = []

# Functions
def getIppVersion() -> str: ...

def setUseIPP(flag: bool) -> None: ...

def setUseIPP_NotExact(flag: bool) -> None: ...

def useIPP() -> bool: ...

def useIPP_NotExact() -> bool: ...


